
function Z = Field_Generator(InversionParameters)
%%%  2D-Simulation

%% Data for simulation
seed = InversionParameters.seed; % Seed generator
nl = InversionParameters.nl; % numbers of lines 

c = InversionParameters.c; % Variogram sill

ap = InversionParameters.ap; % minor axis
ag = InversionParameters.ag; % major axis
theta = InversionParameters.theta; % anisotropic angle

nx = InversionParameters.nx; % Field size in x-direction
ny = InversionParameters.ny; % Field size in y-direction
nz = InversionParameters.nz; % Field size in z-direction
%% Grid Data
x0=grille3(1,nx,1,1,ny,1,1,nz,1);

%% Define the covariance function  
model = [4 ap ag 1 0 0 theta];

%% Compute the spectral density 
%Spectral density computation
[F1,s]=DensSpec1D(x0,model,c);

%% Compute the rotation matrix 
x0rot=ReduceCoord(x0,model);

%% Sample the frequency vector
fv = sample_n_frequencyvector(F1, s, nl, 5);

%% Sampling random phase
U = rand(1, nl);

%% Generate Gaussian fields
Z=STBM_given_phase(x0rot, fv, U, c);
