function [h]=FlowSimulation(FlowParameters)

nx    = FlowParameters.nx;    % x - Data Grid size
ny    = FlowParameters.ny;    % y - Data Grid size
Z     = FlowParameters.Z ;    % Log - hydraulic conductivity field
BC    = FlowParameters.BC;    % Boundary conditions
Kmean = FlowParameters.Kmean; % log- mean of the hydraulic conductivity

%% Grid, petrophysics, and fluid objects

% The grid and rock model
G = cartGrid([nx,ny],[1000,1000]);
G = computeGeometry(G);
rock = makeRock(G, 1, 0.3);
rock.perm=10.^(Z(1:nx*ny)+log10(Kmean*darcy));

% Fluid properties
fluid      = initSingleFluid('mu' ,    1*centi*poise, ...
    'rho', 1000*kilogram/meter^3);
                                                     
% Boundary conditions: fixed pressure at E-W sides and no-flow elsewhere
bc  = pside([], G, 'EAST', 9.80638*1000*BC(1), 'sat', 1);
bc  = pside(bc, G, 'WEST', 9.80638*1000*BC(2), 'sat', 1);

% Initialisation of the first pressure-field
initSol=initResSol(G, 0.0,1);

% Compute the pressure field
T   = computeTrans(G, rock);
sol = incompTPFA(initSol, G, T, fluid, 'bc', bc);

% Transform to hydraulic charge in m
h=sol.pressure*0.000101974;




