function Z=STBM_given_phase(x0, fv, U, c)
% Generate a non-conditional field using the spectral turning band method
% given a phase vector U and an isotropic frequency vector.
% Use for solving inverse problem.

% x0  : Isotropic Data Grid
% fv  : Frequency vector sample from an isotropic spectral density of a covariance function 
% rot : rotation matrix
% cx  : dilatation factor
% c   : sill of the variogram

FV.Grid=x0;
FV.fv=fv;
FV.U=U;
FV.c=c;

% Simulation process
Z=STBM(FV);

function Z=STBM(FV)
% Generated Gaussian random field using the spectral turning band method
%input:
%x0  -- Grid (nbpoint x dim)

%FV (structure containing frequency vectors info)
%FV.fv --   Frequency vector sample from an isotropic spectral density of a covariance function   (nl x 3)
%FV.Grid -- Dilation and rotation factor of grid points (n x 3)
%FV.U -- random uniform values (nl x 1)
%FV.c -- Sill

%return:
%Z  -- Random Gaussian field with prescribed covariance

% Authors : Dany Lauzon

nl=length(FV.fv);

%%% Simuation%%%
%Initialization

%Computation of each cosine function
% Sum along the rows 
Z = sqrt(2/nl) * sum(sqrt(FV.c) .* cos(FV.Grid * FV.fv' + 2 * pi * FV.U), 2);


